mystuff/graphics/nsxiv/patches/patch-config_def_h

49 lines
2.1 KiB
Plaintext

Allow to zoom in further when using the -t flag.
The default is tiny on resolutions higher than FullHD.
Index: config.def.h
--- config.def.h.orig
+++ config.def.h
@@ -16,7 +16,7 @@ static const char *DEFAULT_BAR_FG = NULL; /* NULL
static const char *DEFAULT_FONT = "monospace-8";
/* if true, statusbar appears on top of the window */
-static const bool TOP_STATUSBAR = false;
+static const bool TOP_STATUSBAR = true;
#endif /* HAVE_LIBFONTS */
#endif
@@ -57,18 +57,18 @@ static const bool ALPHA_LAYER = false;
* 0 or less means disable cache.
* 100 means use all available memory (but not above CACHE_SIZE_LIMIT).
*/
-static const int CACHE_SIZE_MEM_PERCENTAGE = 3; /* use 3% of total memory for cache */
-static const int CACHE_SIZE_LIMIT = 256 * 1024 * 1024; /* but not above 256MiB */
-static const int CACHE_SIZE_FALLBACK = 32 * 1024 * 1024; /* fallback to 32MiB if we can't determine total memory */
+static const int CACHE_SIZE_MEM_PERCENTAGE = 10; /* use 10% of total memory for cache */
+static const int CACHE_SIZE_LIMIT = 2048 * 1024 * 1024; /* but not above 2GiB */
+static const int CACHE_SIZE_FALLBACK = 512 * 1024 * 1024; /* fallback to 512MiB if we can't determine total memory */
#endif
#ifdef _THUMBS_CONFIG
/* thumbnail sizes in pixels (width == height): */
-static const int thumb_sizes[] = { 32, 64, 96, 128, 160 };
+static const int thumb_sizes[] = { 128, 160, 240, 320, 460 };
/* thumbnail size at startup, index into thumb_sizes[]: */
-static const int THUMB_SIZE = 3;
+static const int THUMB_SIZE = 2;
#endif
#ifdef _MAPPINGS_CONFIG
@@ -86,7 +86,7 @@ static const keymap_t keys[] = {
{ 0, XK_Return, g_switch_mode, None },
{ 0, XK_f, g_toggle_fullscreen, None },
{ 0, XK_b, g_toggle_bar, None },
- { ControlMask, XK_x, g_prefix_external, None },
+ { 0, XK_x, g_prefix_external, None },
{ 0, XK_g, g_first, None },
{ 0, XK_G, g_n_or_last, None },
{ 0, XK_r, g_reload_image, None },